@@ -133,6 +133,7 @@ typedef struct android_chiaki_session_t
 	jmethodID java_session_event_connected_meth;
 	jmethodID java_session_event_login_pin_request_meth;
 	jmethodID java_session_event_quit_meth;
+	jmethodID java_session_event_rumble_meth;
 	jfieldID java_controller_state_buttons;
 	jfieldID java_controller_state_l2_state;
 	jfieldID java_controller_state_r2_state;
@@ -140,6 +141,20 @@ typedef struct android_chiaki_session_t
 	jfieldID java_controller_state_left_y;
 	jfieldID java_controller_state_right_x;
 	jfieldID java_controller_state_right_y;
+	jfieldID java_controller_state_touches;
+	jfieldID java_controller_state_gyro_x;
+	jfieldID java_controller_state_gyro_y;
+	jfieldID java_controller_state_gyro_z;
+	jfieldID java_controller_state_accel_x;
+	jfieldID java_controller_state_accel_y;
+	jfieldID java_controller_state_accel_z;
+	jfieldID java_controller_state_orient_x;
+	jfieldID java_controller_state_orient_y;
+	jfieldID java_controller_state_orient_z;
+	jfieldID java_controller_state_orient_w;
+	jfieldID java_controller_touch_x;
+	jfieldID java_controller_touch_y;
+	jfieldID java_controller_touch_id;
 
 	AndroidChiakiVideoDecoder video_decoder;
 	AndroidChiakiAudioDecoder audio_decoder;
@@ -178,6 +193,14 @@ static void android_chiaki_event_cb(ChiakiEvent *event, void *user)
 			free(reason_str);
 			break;
 		}
+		case CHIAKI_EVENT_RUMBLE:
+			E->CallVoidMethod(env, session->java_session,
+							  session->java_session_event_rumble_meth,
+							  (jint)event->rumble.left,
+							  (jint)event->rumble.right);
+			break;
+		default:
+			break;
 	}
 
 	(*global_vm)->DetachCurrentThread(global_vm);
@@ -296,6 +319,7 @@ JNIEXPORT void JNICALL JNI_FCN(sessionCreate)(JNIEnv *env, jobject obj, jobject
 	session->java_session_event_connected_meth = E->GetMethodID(env, session->java_session_class, "eventConnected", "()V");
 	session->java_session_event_login_pin_request_meth = E->GetMethodID(env, session->java_session_class, "eventLoginPinRequest", "(Z)V");
 	session->java_session_event_quit_meth = E->GetMethodID(env, session->java_session_class, "eventQuit", "(ILjava/lang/String;)V");
+	session->java_session_event_rumble_meth = E->GetMethodID(env, session->java_session_class, "eventRumble", "(II)V");
 
 	jclass controller_state_class = E->FindClass(env, BASE_PACKAGE"/ControllerState");
 	session->java_controller_state_buttons = E->GetFieldID(env, controller_state_class, "buttons", "I");
@@ -305,6 +329,22 @@ JNIEXPORT void JNICALL JNI_FCN(sessionCreate)(JNIEnv *env, jobject obj, jobject
 	session->java_controller_state_left_y = E->GetFieldID(env, controller_state_class, "leftY", "S");
 	session->java_controller_state_right_x = E->GetFieldID(env, controller_state_class, "rightX", "S");
 	session->java_controller_state_right_y = E->GetFieldID(env, controller_state_class, "rightY", "S");
+	session->java_controller_state_touches = E->GetFieldID(env, controller_state_class, "touches", "[L"BASE_PACKAGE"/ControllerTouch;");
+	session->java_controller_state_gyro_x = E->GetFieldID(env, controller_state_class, "gyroX", "F");
+	session->java_controller_state_gyro_y = E->GetFieldID(env, controller_state_class, "gyroY", "F");
+	session->java_controller_state_gyro_z = E->GetFieldID(env, controller_state_class, "gyroZ", "F");
+	session->java_controller_state_accel_x = E->GetFieldID(env, controller_state_class, "accelX", "F");
+	session->java_controller_state_accel_y = E->GetFieldID(env, controller_state_class, "accelY", "F");
+	session->java_controller_state_accel_z = E->GetFieldID(env, controller_state_class, "accelZ", "F");
+	session->java_controller_state_orient_x = E->GetFieldID(env, controller_state_class, "orientX", "F");
+	session->java_controller_state_orient_y = E->GetFieldID(env, controller_state_class, "orientY", "F");
+	session->java_controller_state_orient_z = E->GetFieldID(env, controller_state_class, "orientZ", "F");
+	session->java_controller_state_orient_w = E->GetFieldID(env, controller_state_class, "orientW", "F");
+
+	jclass controller_touch_class = E->FindClass(env, BASE_PACKAGE"/ControllerTouch");
+	session->java_controller_touch_x = E->GetFieldID(env, controller_touch_class, "x", "S");
+	session->java_controller_touch_y = E->GetFieldID(env, controller_touch_class, "y", "S");
+	session->java_controller_touch_id = E->GetFieldID(env, controller_touch_class, "id", "B");
 
 	chiaki_session_set_event_cb(&session->session, android_chiaki_event_cb, session);
 	chiaki_session_set_video_sample_cb(&session->session, android_chiaki_video_decoder_video_sample, &session->video_decoder);
@@ -373,7 +413,8 @@ JNIEXPORT void JNICALL JNI_FCN(sessionSetSurface)(JNIEnv *env, jobject obj, jlon
 JNIEXPORT void JNICALL JNI_FCN(sessionSetControllerState)(JNIEnv *env, jobject obj, jlong ptr, jobject controller_state_java)
 {
 	AndroidChiakiSession *session = (AndroidChiakiSession *)ptr;
-	ChiakiControllerState controller_state = { 0 };
+	ChiakiControllerState controller_state;
+	chiaki_controller_state_set_idle(&controller_state);
 	controller_state.buttons = (uint32_t)E->GetIntField(env, controller_state_java, session->java_controller_state_buttons);
 	controller_state.l2_state = (uint8_t)E->GetByteField(env, controller_state_java, session->java_controller_state_l2_state);
 	controller_state.r2_state = (uint8_t)E->GetByteField(env, controller_state_java, session->java_controller_state_r2_state);
@@ -381,6 +422,34 @@ JNIEXPORT void JNICALL JNI_FCN(sessionSetControllerState)(JNIEnv *env, jobject o
 	controller_state.left_y = (int16_t)E->GetShortField(env, controller_state_java, session->java_controller_state_left_y);
 	controller_state.right_x = (int16_t)E->GetShortField(env, controller_state_java, session->java_controller_state_right_x);
 	controller_state.right_y = (int16_t)E->GetShortField(env, controller_state_java, session->java_controller_state_right_y);
+	jobjectArray touch_array = E->GetObjectField(env, controller_state_java, session->java_controller_state_touches);
+	size_t touch_array_len = (size_t)E->GetArrayLength(env, touch_array);
+	for(size_t i = 0; i < CHIAKI_CONTROLLER_TOUCHES_MAX; i++)
+	{
+		if(i < touch_array_len)
+		{
+			jobject touch = E->GetObjectArrayElement(env, touch_array, i);
+			controller_state.touches[i].x = (uint16_t)E->GetShortField(env, touch, session->java_controller_touch_x);
+			controller_state.touches[i].y = (uint16_t)E->GetShortField(env, touch, session->java_controller_touch_y);
+			controller_state.touches[i].id = (int8_t)E->GetByteField(env, touch, session->java_controller_touch_id);
+		}
+		else
+		{
+			controller_state.touches[i].x = 0;
+			controller_state.touches[i].y = 0;
+			controller_state.touches[i].id = -1;
+		}
+	}
+	controller_state.gyro_x = E->GetFloatField(env, controller_state_java, session->java_controller_state_gyro_x);
+	controller_state.gyro_y = E->GetFloatField(env, controller_state_java, session->java_controller_state_gyro_y);
+	controller_state.gyro_z = E->GetFloatField(env, controller_state_java, session->java_controller_state_gyro_z);
+	controller_state.accel_x = E->GetFloatField(env, controller_state_java, session->java_controller_state_accel_x);
+	controller_state.accel_y = E->GetFloatField(env, controller_state_java, session->java_controller_state_accel_y);
+	controller_state.accel_z = E->GetFloatField(env, controller_state_java, session->java_controller_state_accel_z);
+	controller_state.orient_x = E->GetFloatField(env, controller_state_java, session->java_controller_state_orient_x);
+	controller_state.orient_y = E->GetFloatField(env, controller_state_java, session->java_controller_state_orient_y);
+	controller_state.orient_z = E->GetFloatField(env, controller_state_java, session->java_controller_state_orient_z);
+	controller_state.orient_w = E->GetFloatField(env, controller_state_java, session->java_controller_state_orient_w);
 	chiaki_session_set_controller_state(&session->session, &controller_state);
 }
 
