@@ -540,10 +540,8 @@ quit:
 #undef QUIT
 }
 
-
-
-
-typedef struct session_response_t {
+typedef struct session_response_t
+{
 	uint32_t error_code;
 	const char *nonce;
 	const char *rp_version;
@@ -596,11 +594,11 @@ static ChiakiErrorCode session_thread_request_session(ChiakiSession *session, Ch
 		set_port(sa, htons(SESSION_PORT));
 
 		// TODO: this can block, make cancelable somehow
-		int r = getnameinfo(sa, (socklen_t)ai->ai_addrlen, session->connect_info.hostname, sizeof(session->connect_info.hostname), NULL, 0, 0);
+		int r = getnameinfo(sa, (socklen_t)ai->ai_addrlen, session->connect_info.hostname, sizeof(session->connect_info.hostname), NULL, 0, NI_NUMERICHOST);
 		if(r != 0)
 		{
-			free(sa);
-			continue;
+			CHIAKI_LOGE(session->log, "getnameinfo failed with %s, filling the hostname with fallback", gai_strerror(r));
+			memcpy(session->connect_info.hostname, "unknown", 8);
 		}
 
 		CHIAKI_LOGI(session->log, "Trying to request session from %s:%d", session->connect_info.hostname, SESSION_PORT);
@@ -611,7 +609,7 @@ static ChiakiErrorCode session_thread_request_session(ChiakiSession *session, Ch
 #ifdef _WIN32
 			CHIAKI_LOGE(session->log, "Failed to create socket to request session");
 #else
-            CHIAKI_LOGE(session->log, "Failed to create socket to request session: %s", strerror(errno));
+			CHIAKI_LOGE(session->log, "Failed to create socket to request session: %s", strerror(errno));
 #endif
 			free(sa);
 			continue;
@@ -652,7 +650,6 @@ static ChiakiErrorCode session_thread_request_session(ChiakiSession *session, Ch
 		break;
 	}
 
-
 	if(CHIAKI_SOCKET_IS_INVALID(session_sock))
 	{
 		CHIAKI_LOGE(session->log, "Session request connect failed eventually.");
